StabilityType

Trait StabilityType 

pub trait StabilityType {
    const VALUE: Stability;
}
Same as Stability, but in the form of a trait. Used when the stability should be encoded in the type.

When/if the adt_const_params Rust feature is stabilized, this could be replace by using Stability directly with const generics.

Required Associated Constants

const VALUE: Stability

The Stability represented by this type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors