pub trait ToAsyncInterface<P>{
type Target: ?Sized;
}Expand description
Implemented by sync interfaces to specify what the associated async interface is. Generic to handle the fact that async interfaces are generic over a thread pool.
The binder in any object implementing this trait should be compatible with the
Target associated type, and using FromIBinder to convert it to the target
should not fail.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".