Interface

Trait Interface 

pub trait Interface:
    Send
    + Sync
    + DowncastSync {
    // Provided methods
    fn as_binder(&self) -> SpIBinder { ... }
    fn dump(
        &self,
        _writer: &mut dyn Write,
        _args: &[&CStr],
    ) -> Result<(), StatusCode> { ... }
}
Super-trait for Binder interfaces.

This trait allows conversion of a Binder interface trait object into an IBinder object for IPC calls. All Binder remotable interface (i.e. AIDL interfaces) must implement this trait.

This is equivalent IInterface in C++.

Provided Methods

fn as_binder(&self) -> SpIBinder

Convert this binder object into a generic SpIBinder reference.

fn dump( &self, _writer: &mut dyn Write, _args: &[&CStr], ) -> Result<(), StatusCode>

Dump transaction handler for this Binder object.

This handler is a no-op by default and should be implemented for each Binder service struct that wishes to respond to dump transactions.

Implementations

Source

impl dyn Interface

pub fn is<__T: Interface>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: Interface>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: Interface>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: Interface>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: Interface>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_arc<__T: Interface + Any + Send + Sync>( self: Arc<Self>, ) -> Result<Arc<__T>, Arc<Self>>

Returns an Arc-ed object from an Arc-ed trait object if the underlying object is of type __T. Returns the original Arc-ed trait if it isn’t.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Interface for ()

Implementors